@@ -16,6 +16,9 @@
 (function () {
   'use strict';
 
+  var READONLY_PROPERTIES = ['os_hash_algo', 'os_hash_value'];
+  var DUPLICATE_PROPERTIES = ['description'];
+
   angular
     .module('horizon.framework.widgets.metadata.tree')
     .controller('MetadataTreeItemController', MetadataTreeItemController);
@@ -32,6 +35,17 @@
     ctrl.formatErrorMessage = formatErrorMessage;
     ctrl.opened = false;
 
+    if ('item' in ctrl && 'leaf' in ctrl.item &&
+      READONLY_PROPERTIES.includes(ctrl.item.leaf.name)) {
+      ctrl.item.leaf.readonly = true;
+      ctrl.item.leaf.required = false;
+    }
+
+    if ('item' in ctrl && 'leaf' in ctrl.item &&
+      DUPLICATE_PROPERTIES.includes(ctrl.item.leaf.name)) {
+      delete ctrl.item;
+    }
+
     if ('item' in ctrl && 'leaf' in ctrl.item && ctrl.item.leaf.type === 'array') {
       ctrl.values = ctrl.item.leaf.items.enum.filter(filter).sort();
 
