@@ -56,6 +56,7 @@
       this.default = null;
       this.type = 'string';
       this.readonly = false;
+      this.required = true;
       this.operators = ['<in>'];
       angular.extend(this, json);
       this.operator = this.operators[0];
@@ -70,9 +71,16 @@
     Property.prototype.setValue = function (value) {
       if (value === null) {
         this.value = this.type !== 'array' ? null : [];
+        // if the existing property is null, make the field not required
+        this.required = false;
         return;
       }
 
+      // if the existing property has empty string value, make the field not required
+      if (value === '') {
+        this.required = false;
+      }
+
       switch (this.type) {
         case 'integer':
           this.value = parseInt(value, 10);
@@ -82,7 +90,7 @@
           break;
         case 'array':
           var data = /^(<.*?>) (.*)$/.exec(value);
-          if (data) {
+          if (data && data.length > 2) {
             this.operator = data[1];
             this.value = data[2].split(',');
           }
@@ -440,7 +448,11 @@
       var existing = {};
       angular.forEach(this.flatTree, function (item) {
         if (item.added && item.leaf) {
-          existing[item.leaf.name] = item.getLeafValue();
+          if (item.leaf.type === 'array' && item.leaf.value.length === 0) {
+            // Do nothing, the user has removed or not selected any array values
+          } else {
+            existing[item.leaf.name] = item.getLeafValue();
+          }
         }
       });
       return existing;
