@@ -27,7 +27,7 @@ register = template.Library()
 
 @register.filter("truncate")
 def truncate(value, size):
+    # pylint: disable=chained-comparison
     if len(value) > size and size > 3:
         return value[0:(size - 3)] + '...'
-    else:
-        return value[0:size]
+    return value[0:size]
