@@ -45,15 +45,26 @@ class IsA(object):
         return isinstance(other, self.cls)
 
 
-class OpenStackAuthTestsMixin(object):
-    """Common functions for version specific tests."""
+class SwitchProviderTests(test.TestCase):
 
-    scenarios = [
-        ('pure', {'interface': None}),
-        ('public', {'interface': 'publicURL'}),
-        ('internal', {'interface': 'internalURL'}),
-        ('admin', {'interface': 'adminURL'})
-    ]
+    interface = None
+
+    def setUp(self):
+        super().setUp()
+
+        params = {
+            'OPENSTACK_API_VERSIONS': {'identity': 3},
+            'OPENSTACK_KEYSTONE_URL': "http://localhost/identity/v3",
+        }
+        if self.interface:
+            params['OPENSTACK_ENDPOINT_TYPE'] = self.interface
+
+        override = self.settings(**params)
+        override.enable()
+        self.addCleanup(override.disable)
+
+        self.data = data_v3.generate_test_data()
+        self.ks_client_module = client_v3
 
     def get_form_data(self, user):
         return {'region': "default",
@@ -61,22 +72,6 @@ class OpenStackAuthTestsMixin(object):
                 'password': user.password,
                 'username': user.name}
 
-
-class OpenStackAuthTestsV3Base(OpenStackAuthTestsMixin, test.TestCase):
-
-    def setUp(self):
-        super().setUp()
-
-        if getattr(self, 'interface', None):
-            override = self.settings(OPENSTACK_ENDPOINT_TYPE=self.interface)
-            override.enable()
-            self.addCleanup(override.disable)
-
-        self.data = data_v3.generate_test_data()
-        self.ks_client_module = client_v3
-        settings.OPENSTACK_API_VERSIONS['identity'] = 3
-        settings.OPENSTACK_KEYSTONE_URL = "http://localhost/identity/v3"
-
     @mock.patch.object(v3_auth, 'Keystone2Keystone')
     @mock.patch.object(client_v3, 'Client')
     @mock.patch.object(v3_auth, 'Token')
@@ -709,7 +704,19 @@ class OpenStackAuthTestsV3Base(OpenStackAuthTestsMixin, test.TestCase):
             IsA(session.Session))
 
 
-class OpenStackAuthTestsWebSSO(OpenStackAuthTestsMixin, test.TestCase):
+class SwitchProviderTestsPublicURL(SwitchProviderTests):
+    interface = 'publicURL'
+
+
+class SwitchProviderTestsInternalURL(SwitchProviderTests):
+    interface = 'internalURL'
+
+
+class SwitchProviderTestsAdminURL(SwitchProviderTests):
+    interface = 'adminURL'
+
+
+class OpenStackAuthTestsWebSSO(test.TestCase):
 
     def setUp(self):
         super().setUp()
@@ -967,7 +974,6 @@ class OpenStackAuthTestsWebSSO(OpenStackAuthTestsMixin, test.TestCase):
                         (settings.OPENSTACK_KEYSTONE_URL, protocol, origin))
 
         url = reverse('login')
-
         # POST to the page and redirect to keystone.
         response = self.client.get(url)
         self.assertRedirects(response, redirect_url, status_code=302,
@@ -987,7 +993,25 @@ class OpenStackAuthTestsWebSSO(OpenStackAuthTestsMixin, test.TestCase):
                              status_code=302, target_status_code=301)
 
 
-class OpenStackAuthTestsV3WithMock(test.TestCase):
+class OpenStackAuthTests(test.TestCase):
+
+    interface = None
+
+    def setUp(self):
+        super().setUp()
+
+        params = {
+            'OPENSTACK_API_VERSIONS': {'identity': 3},
+            'OPENSTACK_KEYSTONE_URL': "http://localhost/identity/v3",
+        }
+        if self.interface:
+            params['OPENSTACK_ENDPOINT_TYPE'] = self.interface
+
+        override = self.settings(**params)
+        override.enable()
+        self.addCleanup(override.disable)
+
+        self.data = data_v3.generate_test_data()
 
     def get_form_data(self, user):
         return {'region': "default",
@@ -995,18 +1019,6 @@ class OpenStackAuthTestsV3WithMock(test.TestCase):
                 'password': user.password,
                 'username': user.name}
 
-    def setUp(self):
-        super(OpenStackAuthTestsV3WithMock, self).setUp()
-
-        if getattr(self, 'interface', None):
-            override = self.settings(OPENSTACK_ENDPOINT_TYPE=self.interface)
-            override.enable()
-            self.addCleanup(override.disable)
-
-        self.data = data_v3.generate_test_data()
-        settings.OPENSTACK_API_VERSIONS['identity'] = 3
-        settings.OPENSTACK_KEYSTONE_URL = "http://localhost:5000/v3"
-
     @mock.patch('keystoneauth1.identity.v3.Token.get_access')
     @mock.patch('keystoneauth1.identity.v3.Password.get_access')
     @mock.patch('keystoneclient.v3.client.Client')
@@ -1110,22 +1122,18 @@ class OpenStackAuthTestsV3WithMock(test.TestCase):
         self.assertContains(response, 'id="id_domain"')
         self.assertContains(response, 'name="domain"')
 
+    @override_settings(
+        OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT=True,
+        OPENSTACK_KEYSTONE_DOMAIN_DROPDOWN=True,
+        OPENSTACK_KEYSTONE_DOMAIN_CHOICES=(('Default', 'Default'),)
+    )
     def test_login_form_multidomain_dropdown(self):
-        override = self.settings(OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT=True,
-                                 OPENSTACK_KEYSTONE_DOMAIN_DROPDOWN=True,
-                                 OPENSTACK_KEYSTONE_DOMAIN_CHOICES=(
-                                     ('Default', 'Default'),)
-                                 )
-        override.enable()
-        self.addCleanup(override.disable)
-
         url = reverse('login')
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
         self.assertContains(response, 'id="id_domain"')
         self.assertContains(response, 'name="domain"')
         self.assertContains(response, 'option value="Default"')
-        settings.OPENSTACK_KEYSTONE_DOMAIN_DROPDOWN = False
 
     @mock.patch.object(projects.ProjectManager, 'list')
     def test_tenant_sorting(self, mock_project_list):
@@ -1373,3 +1381,63 @@ class OpenStackAuthTestsV3WithMock(test.TestCase):
 
     def test_switch_region_with_next(self, next=None):
         self.test_switch_region(next='/next_url')
+
+    @mock.patch.object(v3_auth.Token, 'get_access')
+    @mock.patch.object(password.PasswordPlugin, 'list_projects')
+    @mock.patch.object(v3_auth.Password, 'get_access')
+    def test_switch_system_scope(self, mock_get_access, mock_project_list,
+                                 mock_get_access_token,
+                                 next=None):
+        projects = []
+        user = self.data.user
+        scoped = self.data.unscoped_access_info
+
+        form_data = self.get_form_data(user)
+
+        mock_get_access.return_value = self.data.unscoped_access_info
+        mock_get_access_token.return_value = scoped
+        mock_project_list.return_value = projects
+
+        url = reverse('login')
+
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+
+        response = self.client.post(url, form_data)
+        self.assertRedirects(response, settings.LOGIN_REDIRECT_URL)
+
+        self.assertFalse(self.client.session['token'].system_scoped)
+
+        url = reverse('switch_system_scope')
+
+        if next:
+            form_data.update({auth.REDIRECT_FIELD_NAME: next})
+
+        response = self.client.get(url, form_data)
+
+        if next:
+            expected_url = next
+            self.assertEqual(response['location'], expected_url)
+        else:
+            self.assertRedirects(response, settings.LOGIN_REDIRECT_URL)
+
+        self.assertNotEqual(False, self.client.session['token'].system_scoped)
+
+        mock_get_access.assert_called_once_with(IsA(session.Session))
+        mock_get_access_token.assert_called_with(IsA(session.Session))
+        mock_project_list.assert_called_once_with(
+            IsA(session.Session),
+            IsA(v3_auth.Password),
+            self.data.unscoped_access_info)
+
+
+class OpenStackAuthTestsPublicURL(OpenStackAuthTests):
+    interface = 'publicURL'
+
+
+class OpenStackAuthTestsInternalURL(OpenStackAuthTests):
+    interface = 'internalURL'
+
+
+class OpenStackAuthTestsAdminURL(OpenStackAuthTests):
+    interface = 'adminURL'
