@@ -16,24 +16,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import collections
+import collections.abc
 import functools
 
 from django.conf import settings
 import semantic_version
-import six
 
 from horizon import exceptions
 
-# Python 3.8 removes the ability to import the abstract base classes from
-# 'collections', but 'collections.abc' is not present in Python 2.7
-# TODO(stephenfin): Remove when we drop support for Python 2.7
-# pylint: disable=ungrouped-imports
-if hasattr(collections, 'abc'):
-    from collections.abc import Sequence
-else:
-    from collections import Sequence
-
 
 __all__ = ('APIResourceWrapper', 'APIDictWrapper',
            'get_service_from_catalog', 'url_for',)
@@ -121,7 +111,7 @@ class APIVersionManager(object):
         # Provide a helpful error message if the specified version isn't in the
         # supported list.
         if version not in self.supported:
-            choices = ", ".join(str(k) for k in six.iterkeys(self.supported))
+            choices = ", ".join(str(k) for k in self.supported)
             msg = ('%s is not a supported API version for the %s service, '
                    ' choices are: %s' % (version, self.service_type, choices))
             raise exceptions.ConfigurationError(msg)
@@ -230,7 +220,7 @@ class Quota(object):
         return "<Quota: (%s, %s)>" % (self.name, self.limit)
 
 
-class QuotaSet(Sequence):
+class QuotaSet(collections.abc.Sequence):
     """Wrapper for client QuotaSet objects.
 
     This turns the individual quotas into Quota objects
@@ -303,17 +293,9 @@ def get_service_from_catalog(catalog, service_type):
     return None
 
 
-def get_version_from_service(service):
-    if service and service.get('endpoints'):
-        endpoint = service['endpoints'][0]
-        if 'interface' in endpoint:
-            return 3
-        else:
-            return 2.0
-    return 2.0
-
-
 # Mapping of V2 Catalog Endpoint_type to V3 Catalog Interfaces
+# TODO(e0ne): remove this mapping once OPENSTACK_ENDPOINT_TYPE config option
+#  will be removed.
 ENDPOINT_TYPE_TO_INTERFACE = {
     'publicURL': 'public',
     'internalURL': 'internal',
@@ -325,31 +307,25 @@ def get_url_for_service(service, region, endpoint_type):
     if 'type' not in service:
         return None
 
-    identity_version = get_version_from_service(service)
     service_endpoints = service.get('endpoints', [])
     available_endpoints = [endpoint for endpoint in service_endpoints
                            if region == _get_endpoint_region(endpoint)]
-    """if we are dealing with the identity service and there is no endpoint
-    in the current region, it is okay to use the first endpoint for any
-    identity service endpoints and we can assume that it is global
-    """
+    # if we are dealing with the identity service and there is no endpoint
+    # in the current region, it is okay to use the first endpoint for any
+    # identity service endpoints and we can assume that it is global
     if service['type'] == 'identity' and not available_endpoints:
-        available_endpoints = [endpoint for endpoint in service_endpoints]
+        available_endpoints = service_endpoints
 
     for endpoint in available_endpoints:
         try:
-            if identity_version < 3:
-                return endpoint.get(endpoint_type)
-            else:
-                interface = \
-                    ENDPOINT_TYPE_TO_INTERFACE.get(endpoint_type, '')
-                if endpoint.get('interface') == interface:
-                    return endpoint.get('url')
-        except (IndexError, KeyError):
+            interface = \
+                ENDPOINT_TYPE_TO_INTERFACE.get(endpoint_type, '')
+            if endpoint['interface'] == interface:
+                return endpoint['url']
+        except KeyError:
             # it could be that the current endpoint just doesn't match the
             # type, continue trying the next one
             pass
-    return None
 
 
 def url_for(request, service_type, endpoint_type=None, region=None):
