@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from django.conf import settings
 from django.utils.translation import gettext_lazy as _
 
 import horizon
@@ -29,3 +30,9 @@ class Routers(horizon.Panel):
     def can_register():
         return setting_utils.get_dict_config(
             'OPENSTACK_NEUTRON_NETWORK', 'enable_router')
+
+    def allowed(self, context):
+        if (('network' in settings.SYSTEM_SCOPE_SERVICES) !=
+                bool(context['request'].user.system_scoped)):
+            return False
+        return super().allowed(context)
