@@ -17,7 +17,7 @@ Views for managing Neutron Routers.
 """
 
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from openstack_dashboard import api
