@@ -10,17 +10,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from openstack_dashboard.dashboards.admin.snapshots import views
 
 
 urlpatterns = [
-    url(r'^$', views.SnapshotsView.as_view(), name='index'),
-    url(r'^(?P<snapshot_id>[^/]+)$',
-        views.DetailView.as_view(),
-        name='detail'),
-    url(r'^(?P<snapshot_id>[^/]+)/update_status/$',
-        views.UpdateStatusView.as_view(),
-        name='update_status'),
+    re_path(r'^$', views.SnapshotsView.as_view(), name='index'),
+    re_path(r'^(?P<snapshot_id>[^/]+)$',
+            views.DetailView.as_view(),
+            name='detail'),
+    re_path(r'^(?P<snapshot_id>[^/]+)/update_status/$',
+            views.UpdateStatusView.as_view(),
+            name='update_status'),
 ]
