@@ -13,7 +13,7 @@
 #    under the License.
 
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import messages
@@ -72,7 +72,7 @@ class UpdateDomainView(workflows.WorkflowView):
     workflow_class = project_workflows.UpdateDomain
 
     def get_initial(self):
-        initial = super(UpdateDomainView, self).get_initial()
+        initial = super().get_initial()
 
         domain_id = self.kwargs['domain_id']
         initial['domain_id'] = domain_id
