@@ -12,8 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import url
-from django.utils.translation import ugettext_lazy as _
+from django.urls import re_path
+from django.utils.translation import gettext_lazy as _
 
 from horizon.browsers.views import AngularIndexView
 
@@ -24,12 +24,12 @@ if setting_utils.get_dict_config('ANGULAR_FEATURES', 'roles_panel'):
     # New angular panel
     title = _('Roles')
     urlpatterns = [
-        url(r'^$', AngularIndexView.as_view(title=title), name='index'),
+        re_path(r'^$', AngularIndexView.as_view(title=title), name='index'),
     ]
 else:
     urlpatterns = [
-        url(r'^$', views.IndexView.as_view(), name='index'),
-        url(r'^(?P<role_id>[^/]+)/update/$',
-            views.UpdateView.as_view(), name='update'),
-        url(r'^create/$', views.CreateView.as_view(), name='create'),
+        re_path(r'^$', views.IndexView.as_view(), name='index'),
+        re_path(r'^(?P<role_id>[^/]+)/update/$',
+                views.UpdateView.as_view(), name='update'),
+        re_path(r'^create/$', views.CreateView.as_view(), name='create'),
     ]
