@@ -22,7 +22,7 @@ Views for managing floating IPs.
 """
 
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from neutronclient.common import exceptions as neutron_exc
 
