@@ -21,7 +21,7 @@
 Views for managing Images and Snapshots.
 """
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import messages
