@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
 from django.http import HttpResponse
 from django.template import defaultfilters as filters
 from django.urls import NoReverseMatch
@@ -21,10 +20,10 @@ from django.utils import html
 from django.utils.http import urlencode
 from django.utils import safestring
 from django.utils.text import format_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from django.utils.translation import npgettext_lazy
 from django.utils.translation import pgettext_lazy
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
 
 from horizon import exceptions
 from horizon import messages
@@ -97,7 +96,7 @@ class DeleteVolume(VolumePolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete Volume",
             "Delete Volumes",
             count
@@ -105,7 +104,7 @@ class DeleteVolume(VolumePolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Scheduled deletion of Volume",
             "Scheduled deletion of Volumes",
             count
@@ -572,11 +571,7 @@ class VolumesTable(VolumesTableBase):
         table_actions = (CreateVolume, AcceptTransfer, DeleteVolume,
                          VolumesFilterAction)
 
-        launch_actions = ()
-        if settings.LAUNCH_INSTANCE_LEGACY_ENABLED:
-            launch_actions = (LaunchVolume,) + launch_actions
-        if settings.LAUNCH_INSTANCE_NG_ENABLED:
-            launch_actions = (LaunchVolumeNG,) + launch_actions
+        launch_actions = (LaunchVolumeNG,)
 
         row_actions = ((EditVolume, ExtendVolume,) +
                        launch_actions +
