@@ -25,7 +25,7 @@ from django.urls import reverse
 from django.urls import reverse_lazy
 from django.utils.decorators import method_decorator
 from django.utils import encoding
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views.decorators.cache import never_cache
 from django.views import generic
 
@@ -33,6 +33,7 @@ from horizon import exceptions
 from horizon import forms
 from horizon import tables
 from horizon import tabs
+from horizon.utils import http as http_utils
 from horizon.utils import memoized
 
 from openstack_dashboard.api import cinder
@@ -278,7 +279,7 @@ class CreateView(forms.ModalFormView):
                 _("If \"No volume type\" is selected, the volume will be "
                   "created without a volume type.")
 
-            no_type_description = encoding.force_text(message)
+            no_type_description = encoding.force_str(message)
 
         type_descriptions = [{'name': '',
                               'description': no_type_description}] + \
@@ -566,7 +567,7 @@ class EditAttachmentsView(tables.DataTableView, forms.ModalFormView):
         else:
             context['show_attach'] = False
         context['volume'] = volume
-        if self.request.is_ajax():
+        if http_utils.is_ajax(self.request):
             context['hide'] = True
         return context
 
