@@ -45,6 +45,10 @@ def data(TEST):
     TEST.neutron_quota_usages = utils.TestDataContainer()
     TEST.ip_availability = utils.TestDataContainer()
     TEST.qos_policies = utils.TestDataContainer()
+    TEST.dscp_mark_rule = utils.TestDataContainer()
+    TEST.bandwidth_limit_rule = utils.TestDataContainer()
+    TEST.minimum_bandwidth_rule = utils.TestDataContainer()
+    TEST.minimum_packet_rate_rule = utils.TestDataContainer()
     TEST.rbac_policies = utils.TestDataContainer()
     TEST.tp_ports = utils.TestDataContainer()
     TEST.neutron_availability_zones = utils.TestDataContainer()
@@ -69,6 +73,10 @@ def data(TEST):
     TEST.api_ip_availability = utils.TestDataContainer()
     TEST.api_rbac_policies = utils.TestDataContainer()
     TEST.api_qos_policies = utils.TestDataContainer()
+    TEST.api_dscp_mark_rule = utils.TestDataContainer()
+    TEST.api_bandwidth_limit_rule = utils.TestDataContainer()
+    TEST.api_minimum_bandwidth_rule = utils.TestDataContainer()
+    TEST.api_minimum_packet_rate_rule = utils.TestDataContainer()
     TEST.api_tp_trunks = utils.TestDataContainer()
     TEST.api_tp_ports = utils.TestDataContainer()
 
@@ -271,7 +279,7 @@ def data(TEST):
     TEST.api_ports.add(port_dict)
     TEST.ports.add(neutron.Port(port_dict))
 
-    # External network.
+    # External not shared network.
     network_dict = {'admin_state_up': True,
                     'id': '9b466b94-213a-4cda-badf-72c102a874da',
                     'name': 'ext_net',
@@ -303,6 +311,162 @@ def data(TEST):
     TEST.networks.add(neutron.Network(network))
     TEST.subnets.add(subnet)
 
+    # External shared network.
+
+    network_dict = {'admin_state_up': True,
+                    'id': 'ed351877-4f7b-4672-8164-20a09e4873d3',
+                    'name': 'ext_net_shared',
+                    'status': 'ACTIVE',
+                    'subnets': ['5c59f875-f242-4df2-96e6-7dcc09d6dfc8'],
+                    'tenant_id': '4',
+                    'router:external': True,
+                    'shared': True}
+    subnet_dict = {'allocation_pools': [{'start': '172.24.14.226.',
+                                         'end': '172.24.14.238'}],
+                   'dns_nameservers': [],
+                   'host_routes': [],
+                   'cidr': '172.24.14.0/28',
+                   'enable_dhcp': False,
+                   'gateway_ip': '172.24.14.225',
+                   'id': '5c59f875-f242-4df2-96e6-7dcc09d6dfc8',
+                   'ip_version': 4,
+                   'name': 'ext_shr_subnet',
+                   'network_id': network_dict['id'],
+                   'tenant_id': network_dict['tenant_id']}
+
+    TEST.api_networks.add(network_dict)
+    TEST.api_subnets.add(subnet_dict)
+
+    network = copy.deepcopy(network_dict)
+    subnet = neutron.Subnet(subnet_dict)
+    network['subnets'] = [subnet]
+    TEST.networks.add(neutron.Network(network))
+    TEST.subnets.add(subnet)
+
+    # tenant external shared network
+    network_dict = {'admin_state_up': True,
+                    'id': '650de90f-d77f-4863-ae98-39e97ad3ea7a',
+                    'name': 'ext_net_shared_tenant1',
+                    'status': 'ACTIVE',
+                    'subnets': ['d0a5bc19-16f0-45cc-a187-0d1bb36de4c6'],
+                    'tenant_id': '1',
+                    'router:external': True,
+                    'shared': True}
+    subnet_dict = {'allocation_pools': [{'start': '172.34.14.226.',
+                                         'end': '172.34.14.238'}],
+                   'dns_nameservers': [],
+                   'host_routes': [],
+                   'cidr': '172.34.14.0/28',
+                   'enable_dhcp': False,
+                   'gateway_ip': '172.34.14.225',
+                   'id': 'd0a5bc19-16f0-45cc-a187-0d1bb36de4c6',
+                   'ip_version': 4,
+                   'name': 'ext_shr_tenant1_subnet',
+                   'network_id': network_dict['id'],
+                   'tenant_id': network_dict['tenant_id']}
+
+    TEST.api_networks.add(network_dict)
+    TEST.api_subnets.add(subnet_dict)
+
+    network = copy.deepcopy(network_dict)
+    subnet = neutron.Subnet(subnet_dict)
+    network['subnets'] = [subnet]
+    TEST.networks.add(neutron.Network(network))
+    TEST.subnets.add(subnet)
+
+    # tenant external non-shared network
+    network_dict = {'admin_state_up': True,
+                    'id': '19c3e662-1635-4876-be41-dbfdef0edd17',
+                    'name': 'ext_net_tenant1',
+                    'status': 'ACTIVE',
+                    'subnets': ['5ba8895c-0b3b-482d-9e42-ce389e1e1fa6'],
+                    'tenant_id': '1',
+                    'router:external': True,
+                    'shared': False}
+    subnet_dict = {'allocation_pools': [{'start': '172.44.14.226.',
+                                         'end': '172.44.14.238'}],
+                   'dns_nameservers': [],
+                   'host_routes': [],
+                   'cidr': '172.44.14.0/28',
+                   'enable_dhcp': False,
+                   'gateway_ip': '172.44.14.225',
+                   'id': '5ba8895c-0b3b-482d-9e42-ce389e1e1fa6',
+                   'ip_version': 4,
+                   'name': 'ext_tenant1_subnet',
+                   'network_id': network_dict['id'],
+                   'tenant_id': network_dict['tenant_id']}
+
+    TEST.api_networks.add(network_dict)
+    TEST.api_subnets.add(subnet_dict)
+
+    network = copy.deepcopy(network_dict)
+    subnet = neutron.Subnet(subnet_dict)
+    network['subnets'] = [subnet]
+    TEST.networks.add(neutron.Network(network))
+    TEST.subnets.add(subnet)
+
+    # tenant non-external shared network
+    network_dict = {'admin_state_up': True,
+                    'id': 'fd581273-2601-4057-9c22-1be38f44884e',
+                    'name': 'shr_net_tenant1',
+                    'status': 'ACTIVE',
+                    'subnets': ['d2668892-bc32-4c89-9c63-961920a831d3'],
+                    'tenant_id': '1',
+                    'router:external': False,
+                    'shared': True}
+    subnet_dict = {'allocation_pools': [{'start': '172.54.14.226.',
+                                         'end': '172.54.14.238'}],
+                   'dns_nameservers': [],
+                   'host_routes': [],
+                   'cidr': '172.54.14.0/28',
+                   'enable_dhcp': False,
+                   'gateway_ip': '172.54.14.225',
+                   'id': 'd2668892-bc32-4c89-9c63-961920a831d3',
+                   'ip_version': 4,
+                   'name': 'shr_tenant1_subnet',
+                   'network_id': network_dict['id'],
+                   'tenant_id': network_dict['tenant_id']}
+
+    TEST.api_networks.add(network_dict)
+    TEST.api_subnets.add(subnet_dict)
+
+    network = copy.deepcopy(network_dict)
+    subnet = neutron.Subnet(subnet_dict)
+    network['subnets'] = [subnet]
+    TEST.networks.add(neutron.Network(network))
+    TEST.subnets.add(subnet)
+
+    # non-tenant non-external non-shared network
+    network_dict = {'admin_state_up': True,
+                    'id': '7377e545-1527-4ce1-869e-caca192bc049',
+                    'name': 'net_tenant20',
+                    'status': 'ACTIVE',
+                    'subnets': ['c2bbd65e-0c0f-4ab9-8723-2dd102104f3d'],
+                    'tenant_id': '20',
+                    'router:external': False,
+                    'shared': False}
+    subnet_dict = {'allocation_pools': [{'start': '172.64.14.226.',
+                                         'end': '172.64.14.238'}],
+                   'dns_nameservers': [],
+                   'host_routes': [],
+                   'cidr': '172.54.14.0/28',
+                   'enable_dhcp': False,
+                   'gateway_ip': '172.64.14.225',
+                   'id': 'c2bbd65e-0c0f-4ab9-8723-2dd102104f3d',
+                   'ip_version': 4,
+                   'name': 'tenant20_subnet',
+                   'network_id': network_dict['id'],
+                   'tenant_id': network_dict['tenant_id']}
+
+    TEST.api_networks.add(network_dict)
+    TEST.api_subnets.add(subnet_dict)
+
+    network = copy.deepcopy(network_dict)
+    subnet = neutron.Subnet(subnet_dict)
+    network['subnets'] = [subnet]
+    TEST.networks.add(neutron.Network(network))
+    TEST.subnets.add(subnet)
+
     # 1st v6 network.
     network_dict = {'admin_state_up': True,
                     'id': '96688ea1-ffa5-78ec-22ca-33aaabfaf775',
@@ -487,26 +651,35 @@ def data(TEST):
     # Security group.
 
     sec_group_1 = {'tenant_id': '1',
+                   'shared': False,
                    'description': 'default',
                    'id': 'faad7c80-3b62-4440-967c-13808c37131d',
                    'name': 'default'}
     sec_group_2 = {'tenant_id': '1',
+                   'shared': False,
                    'description': 'NotDefault',
                    'id': '27a5c9a1-bdbb-48ac-833a-2e4b5f54b31d',
                    'name': 'other_group'}
     sec_group_3 = {'tenant_id': '1',
+                   'shared': False,
                    'description': 'NotDefault',
                    'id': '443a4d7a-4bd2-4474-9a77-02b35c9f8c95',
                    'name': 'another_group'}
     sec_group_empty = {'tenant_id': '1',
+                       'shared': False,
                        'description': 'SG without rules',
                        'id': 'f205f3bc-d402-4e40-b004-c62401e19b4b',
                        'name': 'empty_group'}
+    sec_group_shared = {'tenant_id': '1',
+                        'shared': True,
+                        'description': 'SG without rules',
+                        'id': 'cca53e02-114e-4da3-917b-f19efa7cbc47',
+                        'name': 'shared_group'}
 
     def add_rule_to_group(secgroup, default_only=True):
         rule_egress_ipv4 = {
             'id': uuidutils.generate_uuid(),
-            'direction': u'egress', 'ethertype': u'IPv4',
+            'direction': 'egress', 'ethertype': 'IPv4',
             'port_range_min': None, 'port_range_max': None,
             'protocol': None, 'remote_group_id': None,
             'remote_ip_prefix': None,
@@ -516,7 +689,7 @@ def data(TEST):
         }
         rule_egress_ipv6 = {
             'id': uuidutils.generate_uuid(),
-            'direction': u'egress', 'ethertype': u'IPv6',
+            'direction': 'egress', 'ethertype': 'IPv6',
             'port_range_min': None, 'port_range_max': None,
             'protocol': None, 'remote_group_id': None,
             'remote_ip_prefix': None,
@@ -526,29 +699,29 @@ def data(TEST):
         }
         rule_tcp_80 = {
             'id': uuidutils.generate_uuid(),
-            'direction': u'ingress', 'ethertype': u'IPv4',
+            'direction': 'ingress', 'ethertype': 'IPv4',
             'port_range_min': 80, 'port_range_max': 80,
-            'protocol': u'tcp', 'remote_group_id': None,
-            'remote_ip_prefix': u'0.0.0.0/0',
+            'protocol': 'tcp', 'remote_group_id': None,
+            'remote_ip_prefix': '0.0.0.0/0',
             'security_group_id': secgroup['id'],
             'tenant_id': secgroup['tenant_id'],
             'description': 'Ingress HTTP',
         }
         rule_icmp = {
             'id': uuidutils.generate_uuid(),
-            'direction': u'ingress', 'ethertype': u'IPv4',
+            'direction': 'ingress', 'ethertype': 'IPv4',
             'port_range_min': 5, 'port_range_max': 8,
-            'protocol': u'icmp', 'remote_group_id': None,
-            'remote_ip_prefix': u'0.0.0.0/0',
+            'protocol': 'icmp', 'remote_group_id': None,
+            'remote_ip_prefix': '0.0.0.0/0',
             'security_group_id': secgroup['id'],
             'tenant_id': secgroup['tenant_id'],
             'description': 'Ingress IPv4 ICMP',
         }
         rule_group = {
             'id': uuidutils.generate_uuid(),
-            'direction': u'ingress', 'ethertype': u'IPv4',
+            'direction': 'ingress', 'ethertype': 'IPv4',
             'port_range_min': 80, 'port_range_max': 80,
-            'protocol': u'tcp', 'remote_group_id': sec_group_1['id'],
+            'protocol': 'tcp', 'remote_group_id': sec_group_1['id'],
             'remote_ip_prefix': None,
             'security_group_id': secgroup['id'],
             'tenant_id': secgroup['tenant_id'],
@@ -556,20 +729,20 @@ def data(TEST):
         }
         rule_ip_proto = {
             'id': uuidutils.generate_uuid(),
-            'direction': u'ingress', 'ethertype': u'IPv4',
+            'direction': 'ingress', 'ethertype': 'IPv4',
             'port_range_min': None, 'port_range_max': None,
-            'protocol': u'99', 'remote_group_id': None,
-            'remote_ip_prefix': u'0.0.0.0/24',
+            'protocol': '99', 'remote_group_id': None,
+            'remote_ip_prefix': '0.0.0.0/24',
             'security_group_id': secgroup['id'],
             'tenant_id': secgroup['tenant_id'],
             'description': 'Ingress custom IP protocol 99',
         }
         rule_all_tcp = {
             'id': uuidutils.generate_uuid(),
-            'direction': u'egress', 'ethertype': u'IPv4',
+            'direction': 'egress', 'ethertype': 'IPv4',
             'port_range_min': 1, 'port_range_max': 65535,
-            'protocol': u'tcp', 'remote_group_id': None,
-            'remote_ip_prefix': u'0.0.0.0/24',
+            'protocol': 'tcp', 'remote_group_id': None,
+            'remote_ip_prefix': '0.0.0.0/24',
             'security_group_id': secgroup['id'],
             'tenant_id': secgroup['tenant_id'],
             'description': 'Egress all TCP',
@@ -585,10 +758,11 @@ def data(TEST):
     add_rule_to_group(sec_group_1, default_only=False)
     add_rule_to_group(sec_group_2)
     add_rule_to_group(sec_group_3)
-    # NOTE: sec_group_empty is a SG without rules,
+    # NOTE: sec_group_empty and sec_group_shared are SGs without rules,
     # so we don't call add_rule_to_group.
 
-    groups = [sec_group_1, sec_group_2, sec_group_3, sec_group_empty]
+    groups = [sec_group_1, sec_group_2, sec_group_3,
+              sec_group_empty, sec_group_shared]
     sg_name_dict = dict([(sg['id'], sg['name']) for sg in groups])
     for sg in groups:
         # Neutron API.
@@ -684,12 +858,17 @@ def data(TEST):
     extension_6 = {"name": "Trunks",
                    "alias": "trunk",
                    "description": "Provides support for trunk ports."}
+    extension_7 = {"name": "Security group filtering on the shared field",
+                   "alias": "security-groups-shared-filtering",
+                   "description": "Support filtering security groups on "
+                                  "the shared field"}
     TEST.api_extensions.add(extension_1)
     TEST.api_extensions.add(extension_2)
     TEST.api_extensions.add(extension_3)
     TEST.api_extensions.add(extension_4)
     TEST.api_extensions.add(extension_5)
     TEST.api_extensions.add(extension_6)
+    TEST.api_extensions.add(extension_7)
 
     # 1st agent.
     agent_dict = {"binary": "neutron-openvswitch-agent",
@@ -792,6 +971,49 @@ def data(TEST):
     TEST.api_qos_policies.add(policy_dict1)
     TEST.qos_policies.add(neutron.QoSPolicy(policy_dict1))
 
+    # qos rule - dscp mark
+    dscp_mark_rule_dict = {
+        "id": "5f126d84-551a-4dcf-bb01-0e9c0df0c794",
+        "dscp_mark": 26,
+        "tenant_id": "1"
+    }
+    TEST.api_dscp_mark_rule.add(dscp_mark_rule_dict)
+    TEST.dscp_mark_rule.add(neutron.DSCPMarkingRule(dscp_mark_rule_dict))
+
+    # qos rule - bandwidth limit
+    bandwidth_limit_rule = {
+        "id": "5f126d84-551a-4dcf-bb01-0e9c0df0c793",
+        "max_kbps": 10000,
+        "max_burst_kbps": 0,
+        "direction": "egress",
+        "tenant_id": "1"
+    }
+    TEST.api_bandwidth_limit_rule.add(bandwidth_limit_rule)
+    TEST.bandwidth_limit_rule.add(neutron.BandwidthLimitRule(
+        bandwidth_limit_rule))
+
+    # qos rule - minimum bandwidth
+    minimum_bandwidth_rule = {
+        "id": "1eddf7af-0b4c-42c5-8ae1-390b32f1de08",
+        "min_kbps": 10000,
+        "direction": "egress",
+        "tenant_id": "1"
+    }
+    TEST.api_minimum_bandwidth_rule.add(minimum_bandwidth_rule)
+    TEST.minimum_bandwidth_rule.add(neutron.MinimumBandwidthRule(
+        minimum_bandwidth_rule))
+
+    # qos rule - minimum packet rate
+    minimum_packet_rate_rule = {
+        "id": "1eddf7af-0b4c-42c5-8ae1-390b32f1de08",
+        "min_kpps": 10000,
+        "direction": "egress",
+        "tenant_id": "1"
+    }
+    TEST.api_minimum_packet_rate_rule.add(minimum_packet_rate_rule)
+    TEST.minimum_packet_rate_rule.add(neutron.MinimumPacketRateRule(
+        minimum_packet_rate_rule))
+
     # rbac policies
     rbac_policy_dict = {"project_id": "1",
                         "object_type": "network",
@@ -867,7 +1089,7 @@ def data(TEST):
         'sub_ports': [{'segmentation_type': 'vlan',
                        'segmentation_id': tdata['tag_1'],
                        'port_id': tdata['child1']['id']},
-                      {'segmentation_type': u'vlan',
+                      {'segmentation_type': 'vlan',
                        'segmentation_id': tdata['tag_2'],
                        'port_id': tdata['child2']['id']}],
         'name': 'trunk',
@@ -987,3 +1209,92 @@ def data(TEST):
             'name': 'nova'
         }
     )
+
+
+def list_nets_in_query_order(source_list):
+    return ([n for n in source_list if n['shared'] is True] +
+            [n for n in source_list if (n['tenant_id'] == '1' and
+             n['shared'] is False)] +
+            [n for n in source_list if n['router:external'] is True and
+             n['shared'] is False])
+
+
+source_nets_pagination1 = sorted([
+    neutron.Network({
+        'admin_state_up': True,
+        'id': uuidutils.generate_uuid(),
+        'name': 'net{}'.format(i),
+        'status': 'ACTIVE',
+        'subnets': [],
+        'tenant_id': '1',
+        'router:external': False,
+        'shared': False}) for i in range(0, 58)
+] + [
+    neutron.Network({
+        'admin_state_up': True,
+        'id': uuidutils.generate_uuid(),
+        'name': 'net_ext',
+        'status': 'ACTIVE',
+        'subnets': [],
+        'tenant_id': '2',
+        'router:external': True,
+        'shared': False})
+] + [
+    neutron.Network({
+        'admin_state_up': True,
+        'id': uuidutils.generate_uuid(),
+        'name': 'net_shr',
+        'status': 'ACTIVE',
+        'subnets': [],
+        'tenant_id': '3',
+        'router:external': False,
+        'shared': True})
+], key=lambda net: net['id'])
+
+all_nets_pagination1 = list_nets_in_query_order(source_nets_pagination1)
+
+source_nets_pagination2 = sorted([
+    neutron.Network({
+        'admin_state_up': True,
+        'id': uuidutils.generate_uuid(),
+        'name': 'net{}'.format(i),
+        'status': 'ACTIVE',
+        'subnets': [],
+        'tenant_id': '2',
+        'router:external': True,
+        'shared': False}) for i in range(0, 25)
+] + [
+    neutron.Network({
+        'admin_state_up': True,
+        'id': uuidutils.generate_uuid(),
+        'name': 'net{}'.format(i),
+        'status': 'ACTIVE',
+        'subnets': [],
+        'tenant_id': '3',
+        'router:external': False,
+        'shared': True}) for i in range(0, 25)
+] + [
+    neutron.Network({
+        'admin_state_up': True,
+        'id': uuidutils.generate_uuid(),
+        'name': 'net{}'.format(i),
+        'status': 'ACTIVE',
+        'subnets': [],
+        'tenant_id': '1',
+        'router:external': False,
+        'shared': False}) for i in range(0, 10)
+], key=lambda net: net['id'])
+
+all_nets_pagination2 = list_nets_in_query_order(source_nets_pagination2)
+
+source_nets_pagination3 = sorted([
+    neutron.Network({
+        'admin_state_up': True,
+        'id': uuidutils.generate_uuid(),
+        'name': 'net{}'.format(i),
+        'status': 'ACTIVE',
+        'subnets': [],
+        'tenant_id': '1',
+        'router:external': False,
+        'shared': False}) for i in range(0, 5)
+], key=lambda net: net['id'])
